@@ -261,6 +261,21 @@ void PluginTest::testModel()
     QCOMPARE(model->property("account").value<QObject*>(), account2);
     model->setProperty("account", QVariant::fromValue<QObject*>(0));
 
+    /* Test the application filter */
+    model->setProperty("applicationId", QString("mailer"));
+    QCOMPARE(model->property("applicationId").toString(), QString("mailer"));
+    QTest::qWait(10);
+    QCOMPARE(model->rowCount(), 2);
+    QSet<QString> services;
+    services.insert(get(model, 0, "serviceName").toString());
+    services.insert(get(model, 1, "serviceName").toString());
+    QSet<QString> expectedServices;
+    expectedServices.insert("Cool Mail");
+    expectedServices.insert("Bad Mail");
+    QCOMPARE(services, expectedServices);
+    /* Reset the application filter */
+    model->setProperty("applicationId", QString());
+
     /* Test the provider filter */
     model->setProperty("provider", QString("bad"));
     QCOMPARE(model->property("provider").toString(), QString("bad"));
@@ -584,6 +599,8 @@ void PluginTest::testProviderModel()
         QCOMPARE(get(model, i, "iconName").toString(), providers[i].iconName());
         QCOMPARE(get(model, i, "isSingleAccount").toBool(),
                  providers[i].isSingleAccount());
+        QCOMPARE(get(model, i, "translations").toString(),
+                 providers[i].trCatalog());
     }
 
     QCOMPARE(get(model, 100, "iconName"), QVariant());
@@ -683,6 +700,8 @@ void PluginTest::testAccountService()
     QCOMPARE(provider["id"].toString(), QString("cool"));
     QCOMPARE(provider["displayName"].toString(), QString("Cool provider"));
     QCOMPARE(provider["iconName"].toString(), QString("general_myprovider"));
+    QCOMPARE(provider["isSingleAccount"].toBool(), true);
+    QCOMPARE(provider["translations"].toString(), QString("somewhere"));
 
     QVariantMap service = qmlObject->property("service").toMap();
     QVERIFY(!service.isEmpty());
@@ -690,6 +709,7 @@ void PluginTest::testAccountService()
     QCOMPARE(service["displayName"].toString(), QString("Cool Mail"));
     QCOMPARE(service["iconName"].toString(), QString("general_myservice"));
     QCOMPARE(service["serviceTypeId"].toString(), QString("e-mail"));
+    QCOMPARE(service["translations"].toString(), QString("here"));
 
     QVariantMap settings = qmlObject->property("settings").toMap();
     QVERIFY(!settings.isEmpty());
